Learn R Programming

pmc (version 0.0-8)

mrcaOUCH: Finds the most recent common ancestor on an OUCH formatted tree

Description

Finds the most recent common ancestor on an OUCH formatted tree

Usage

mrcaOUCH(cladeVector, tree)

Arguments

cladeVector
vector of species for which you want to find the most recent common ancestor
tree
an ouchtree class phylogeny

Value

  • the node number of the most recent common ancestor