Learn R Programming

pmc (version 0.0-8)

paintBranches: Paints branches with regimes changing at nodes specified

Description

Paints branches with regimes changing at nodes specified

Usage

paintBranches(regimeShiftNodes, tree,
    regimeTitles = NULL)

Arguments

tree
OUCH-style (S4) tree
regimeShiftNodes
a vector of nodes or a list of taxa defining nodes at which selective regimes shift: root may be included--if not present, will be added--but tips are meaningless in this context
regimeTitles
a vector of titles for the regimes that begin at the root and at the nodes indicated in "regimeShiftNodes", in order of description in "regimeShiftNodes", except that the root is listed first in "regimeTitles" but not at all in "regimeShiftNodes".

Value

  • a vector of regimes that can be handed to hansen